/*
 * STM32F4xx_Framework V1.0
 * @file 	stm32f4xx_Framework.h
 * @brief	This is the unique include file for the STM32F4xx_Framework
 */


/*
 * Supported Devices:
 * 	STM32F40X
 * 	STM32F41X
 *
 * 	This Framework does the minimal configuration of the microcontroller.
 * 	It defines all registers, bits and macros, initializes the Stack and sets up the Vector Table.
 * 	It includes the CMSIS and the ST Standard Peripheral Library to your project.
 * 	You have just to change the defines in stm32f4xx_FrameworkConfig.h according to your application.
 * 	After reset the mikrcontroller is running from internal Oscillator without PLL.
 * 	The Framework does NOT configure the clocks!
 *
 * 	You can configure the Framework through following defines in stm32f4xx_FrameworkConfig.h:
 *
 * 		HSE_VALUE			The frequency of the external oscillator.
 * 							Standard Value: 8000000
 *
 * 		HSE_STARTUP_TIMEOUT	Timeout for HSE.
 * 							Standard Value: 0x500
 *
 * 		HSI_VALUE			The frequency of the internal oscillator.
 * 							Standard Value: 16000000
 *
 * 		STACK_SIZE			Configures the Stack Size (In Words).
 * 							Standard Value: 0x200
 *
 * 		VECT_TAB_OFFSET		Offset of the Vector Table.
 * 							Standard Value: 0x00
 *
 * 		VECT_TAB_SRAM		Locate the Vector Table in SRAM.
 * 							Standard Value: UNDEFINED (Vector Table in FLASH)
 *
 * 		__FPU_USED			If __FPU_USED is defined the Framework will enable the FPU.
 * 							Standard Value: UNDEFINED (FPU is disabled)
 *
 * 		USE_FULL_ASSERT		Enable full assert (Used in ST Standard Peripheral Library).
 * 							You have to add the function void assert_failed(uint8_t* file, uint8_t line)
 * 							to handle wrong parameters in ST Standard Peripheral Library
 * 							Standard Value: UNDEFINED
 */


/*----------Define to prevent recursive inclusion-----------------------------*/
#ifndef __STM32F4XX_FRAMEWORK_H
#define __STM32F4XX_FRAMEWORK_H


/*----------Include----------------------------------------------------------*/
#include "stm32f4xx.h"

#endif
